@@ -1,6 +1,6 @@
 from collections import OrderedDict
 
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from drf_extra_fields.fields import Base64FieldMixin
 from drf_yasg import openapi
